<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Cosme
 */
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function cosme_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'cosme_content_width', 640 );
}
add_action( 'after_setup_theme', 'cosme_content_width', 0 );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function cosme_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'cosme_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function cosme_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'cosme_pingback_header' );

function cosme_archive_grid(){
	$cosme_archive_layout	= get_theme_mod( 'cosme_archive_layout', 'simple' );
	$cosme_archive_grid_columns		= get_theme_mod( 'cosme_archives_grid_columns', '2' );
	if( $cosme_archive_layout == 'simple' ) {
		$cosme_content_class[] 		= 'one-whole';
	}elseif( $cosme_archive_layout == 'classic'){
		$cosme_content_class[] 		= 'classic one-whole';
	}
	else{
		switch( $cosme_archive_grid_columns ){
			case '2':
				$cosme_content_class[]   = 'large--one-half medium--one-half small--one-whole';
				break;
			case '3':
				$cosme_content_class[]   = 'large--one-third medium--one-half small--one-whole';
				break;
			case '4':
				$cosme_content_class[]   = 'large--one-quarter medium--one-half small--one-whole';
				break;
			default:
				$cosme_content_class[]   = 'large--one-half medium--one-half small--one-whole';
		}

	}
	return $cosme_content_class;
}

add_action( 'footer_social', 'cosme_footer_social' );

if( ! function_exists( 'cosme_footer_social' ) ):
	function cosme_footer_social() {
	    $cosme_facebook_link = get_theme_mod( 'cosme_facebook_url', '' );
		$cosme_twitter_link = get_theme_mod( 'cosme_twitter_url', '' );
	    $cosme_linkedin_link = get_theme_mod( 'cosme_linkedin_url', '' );
	    $cosme_instagram_link = get_theme_mod( 'cosme_instagram_url', '' );
	    $cosme_pinterest_link = get_theme_mod( 'cosme_pinterest_url', '' );
	    $cosme_youtube_link = get_theme_mod( 'cosme_youtube_url', '' );
	    $classes = 'round-border-icon';
		?>
	   <ul class="social-icons clearfix <?php echo esc_attr( $classes ); ?>">
		   <?php
			if( ! empty( $cosme_facebook_link ) ): ?>
				<li class="text-center">
					<a href="<?php echo esc_url( $cosme_facebook_link ); ?>" target="_blank"> 
						<svg width="10px" height="20px" viewBox="0 0 10 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
							<g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
								<g id="Dribbble-Light-Preview" transform="translate(-385.000000, -7399.000000)" fill="#000000">
									<g id="icons" transform="translate(56.000000, 160.000000)">
										<path d="M335.821282,7259 L335.821282,7250 L338.553693,7250 L339,7246 L335.821282,7246 L335.821282,7244.052 C335.821282,7243.022 335.847593,7242 337.286884,7242 L338.744689,7242 L338.744689,7239.14 C338.744689,7239.097 337.492497,7239 336.225687,7239 C333.580004,7239 331.923407,7240.657 331.923407,7243.7 L331.923407,7246 L329,7246 L329,7250 L331.923407,7250 L331.923407,7259 L335.821282,7259 Z" id="facebook-[#176]"></path>
									</g>
								</g>
							</g>
						</svg>
					</a>
				</li>
				<?php
			endif;
		    if( ! empty( $cosme_twitter_link ) ): ?>
		        <li class="text-center">
					<a href="<?php echo esc_url( $cosme_twitter_link ); ?>" target="_blank">
						<svg width="20px" height="16px" viewBox="0 0 20 16" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
							<g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
								<g id="Dribbble-Light-Preview" transform="translate(-60.000000, -7521.000000)" fill="#000000">
									<g id="icons" transform="translate(56.000000, 160.000000)">
										<path d="M10.29,7377 C17.837,7377 21.965,7370.84365 21.965,7365.50546 C21.965,7365.33021 21.965,7365.15595 21.953,7364.98267 C22.756,7364.41163 23.449,7363.70276 24,7362.8915 C23.252,7363.21837 22.457,7363.433 21.644,7363.52751 C22.5,7363.02244 23.141,7362.2289 23.448,7361.2926 C22.642,7361.76321 21.761,7362.095 20.842,7362.27321 C19.288,7360.64674 16.689,7360.56798 15.036,7362.09796 C13.971,7363.08447 13.518,7364.55538 13.849,7365.95835 C10.55,7365.79492 7.476,7364.261 5.392,7361.73762 C4.303,7363.58363 4.86,7365.94457 6.663,7367.12996 C6.01,7367.11125 5.371,7366.93797 4.8,7366.62489 L4.8,7366.67608 C4.801,7368.5989 6.178,7370.2549 8.092,7370.63591 C7.488,7370.79836 6.854,7370.82199 6.24,7370.70483 C6.777,7372.35099 8.318,7373.47829 10.073,7373.51078 C8.62,7374.63513 6.825,7375.24554 4.977,7375.24358 C4.651,7375.24259 4.325,7375.22388 4,7375.18549 C5.877,7376.37088 8.06,7377 10.29,7376.99705" id="twitter-[#154]"></path>
									</g>
								</g>
							</g>
						</svg>
					</a>
				</li>
				<?php
		    endif;
			if( ! empty( $cosme_linkedin_link ) ): ?>
		        <li class="text-center">
					<a href="<?php echo esc_url( $cosme_linkedin_link ); ?>" target="_blank">
						<svg width="20px" height="20px" viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
							<g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
								<g id="Dribbble-Light-Preview" transform="translate(-180.000000, -7479.000000)" fill="#000000">
									<g id="icons" transform="translate(56.000000, 160.000000)">
										<path d="M144,7339 L140,7339 L140,7332.001 C140,7330.081 139.153,7329.01 137.634,7329.01 C135.981,7329.01 135,7330.126 135,7332.001 L135,7339 L131,7339 L131,7326 L135,7326 L135,7327.462 C135,7327.462 136.255,7325.26 139.083,7325.26 C141.912,7325.26 144,7326.986 144,7330.558 L144,7339 L144,7339 Z M126.442,7323.921 C125.093,7323.921 124,7322.819 124,7321.46 C124,7320.102 125.093,7319 126.442,7319 C127.79,7319 128.883,7320.102 128.883,7321.46 C128.884,7322.819 127.79,7323.921 126.442,7323.921 L126.442,7323.921 Z M124,7339 L129,7339 L129,7326 L124,7326 L124,7339 Z" id="linkedin-[#161]"></path>
									</g>
								</g>
							</g>
						</svg>
					</a>
				</li>
				<?php
		    endif;
			if( ! empty( $cosme_instagram_link ) ): ?>
		        <li class="text-center">
					<a href="<?php echo esc_url( $cosme_instagram_link ); ?>" target="_blank"> 
						<svg width="20px" height="20px" viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
							<g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
								<g id="Dribbble-Light-Preview" transform="translate(-340.000000, -7439.000000)" fill="#000000">
									<g id="icons" transform="translate(56.000000, 160.000000)">
										<path d="M289.869652,7279.12273 C288.241769,7279.19618 286.830805,7279.5942 285.691486,7280.72871 C284.548187,7281.86918 284.155147,7283.28558 284.081514,7284.89653 C284.035742,7285.90201 283.768077,7293.49818 284.544207,7295.49028 C285.067597,7296.83422 286.098457,7297.86749 287.454694,7298.39256 C288.087538,7298.63872 288.809936,7298.80547 289.869652,7298.85411 C298.730467,7299.25511 302.015089,7299.03674 303.400182,7295.49028 C303.645956,7294.859 303.815113,7294.1374 303.86188,7293.08031 C304.26686,7284.19677 303.796207,7282.27117 302.251908,7280.72871 C301.027016,7279.50685 299.5862,7278.67508 289.869652,7279.12273 M289.951245,7297.06748 C288.981083,7297.0238 288.454707,7296.86201 288.103459,7296.72603 C287.219865,7296.3826 286.556174,7295.72155 286.214876,7294.84312 C285.623823,7293.32944 285.819846,7286.14023 285.872583,7284.97693 C285.924325,7283.83745 286.155174,7282.79624 286.959165,7281.99226 C287.954203,7280.99968 289.239792,7280.51332 297.993144,7280.90837 C299.135448,7280.95998 300.179243,7281.19026 300.985224,7281.99226 C301.980262,7282.98483 302.473801,7284.28014 302.071806,7292.99991 C302.028024,7293.96767 301.865833,7294.49274 301.729513,7294.84312 C300.829003,7297.15085 298.757333,7297.47145 289.951245,7297.06748 M298.089663,7283.68956 C298.089663,7284.34665 298.623998,7284.88065 299.283709,7284.88065 C299.943419,7284.88065 300.47875,7284.34665 300.47875,7283.68956 C300.47875,7283.03248 299.943419,7282.49847 299.283709,7282.49847 C298.623998,7282.49847 298.089663,7283.03248 298.089663,7283.68956 M288.862673,7288.98792 C288.862673,7291.80286 291.150266,7294.08479 293.972194,7294.08479 C296.794123,7294.08479 299.081716,7291.80286 299.081716,7288.98792 C299.081716,7286.17298 296.794123,7283.89205 293.972194,7283.89205 C291.150266,7283.89205 288.862673,7286.17298 288.862673,7288.98792 M290.655732,7288.98792 C290.655732,7287.16159 292.140329,7285.67967 293.972194,7285.67967 C295.80406,7285.67967 297.288657,7287.16159 297.288657,7288.98792 C297.288657,7290.81525 295.80406,7292.29716 293.972194,7292.29716 C292.140329,7292.29716 290.655732,7290.81525 290.655732,7288.98792" id="instagram-[#167]"></path>
									</g>
								</g>
							</g>
						</svg>
					</a>
				</li>
				<?php
		    endif;
			if( ! empty( $cosme_youtube_link ) ): ?>
		        <li class="text-center">
					<a href="<?php echo esc_url( $cosme_youtube_link ); ?>" target="_blank"> 
						<svg width="20px" height="14px" viewBox="0 0 20 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
							<g id="Page-1" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
								<g id="Dribbble-Light-Preview" transform="translate(-300.000000, -7442.000000)" fill="#000000">
									<g id="icons" transform="translate(56.000000, 160.000000)">
										<path d="M251.988432,7291.58588 L251.988432,7285.97425 C253.980638,7286.91168 255.523602,7287.8172 257.348463,7288.79353 C255.843351,7289.62824 253.980638,7290.56468 251.988432,7291.58588 M263.090998,7283.18289 C262.747343,7282.73013 262.161634,7282.37809 261.538073,7282.26141 C259.705243,7281.91336 248.270974,7281.91237 246.439141,7282.26141 C245.939097,7282.35515 245.493839,7282.58153 245.111335,7282.93357 C243.49964,7284.42947 244.004664,7292.45151 244.393145,7293.75096 C244.556505,7294.31342 244.767679,7294.71931 245.033639,7294.98558 C245.376298,7295.33761 245.845463,7295.57995 246.384355,7295.68865 C247.893451,7296.0008 255.668037,7296.17532 261.506198,7295.73552 C262.044094,7295.64178 262.520231,7295.39147 262.895762,7295.02447 C264.385932,7293.53455 264.28433,7285.06174 263.090998,7283.18289" id="youtube-[#168]"></path>
									</g>
								</g>
							</g>
						</svg>
					</a>
				</li>
				<?php
		    endif;
			?>
		<ul>
	<?php
}

endif;


/**
 * Back to top icon
 */


add_action( 'cosme_footer_after', 'scroll_to_top' );

if( !function_exists ('scroll_to_top') ){

	function scroll_to_top() {
		$enable = get_theme_mod( 'enable_scrolltop', 1 );

		if ( !$enable ) {
			return;
		}

		$type 		= get_theme_mod( 'scrolltop_type', 'icon' );			
		$text 		= get_theme_mod( 'scrolltop_text', esc_html__( 'Back to top', 'cosme' ) );	
		$icon		= get_theme_mod( 'scrolltop_icon', 'icon1' );
		$visibility = get_theme_mod( 'scrolltop_visibility', 'all' );
		$position 	= get_theme_mod( 'scrolltop_position', 'right' );

		switch ( $icon ) {
			case 'icon1':
				$scroll_icon = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M5 15L12 8L19 15" stroke-width="1.5" stroke-linejoin="round"/></svg>';
				break;
			
			case 'icon2':
				$scroll_icon = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M5 15l7-7 7 7" stroke-width="3" stroke-linejoin="round"/></svg>';
				break;

			case 'icon3':
				$scroll_icon = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M7 12l5.5-5.5m0 0L18 12m-5.5-5.5V19" stroke-width="1.5" stroke-linejoin="round"/></svg>';
				break;

			case 'icon4':
				$scroll_icon = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M7 12l5.5-5.5m0 0L18 12m-5.5-5.5V19" stroke-width="3" stroke-linejoin="round"/></svg>';
				break;
			
			default:
				$scroll_icon = '<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M5 15L12 8L19 15" stroke-width="1.5" stroke-linejoin="round"/></svg>';
				break;
		}

		echo '<div class="back-to-top visibility-' . esc_attr( $visibility ) . ' position-' . esc_attr( $position ) . '">';
		if ( 'text' === $type ) {
			echo '<span>' . esc_html( $text ) . '</span>';
		}
		echo $scroll_icon; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		echo '</div>';
	}

}

